aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/sandbox/LinuxSandboxedStrategy.java
diff options
context:
space:
mode:
authorGravatar Philipp Wollermann <philwo@google.com>2016-07-15 14:41:54 +0000
committerGravatar Yun Peng <pcloudy@google.com>2016-07-18 10:42:56 +0000
commit278814b0fbf4ddf19d58344481814b8cd6e70c7d (patch)
tree97cd69ea04915d8e66d798eecc42fd720f50ef99 /src/main/java/com/google/devtools/build/lib/sandbox/LinuxSandboxedStrategy.java
parent28764a346a5a2ec4d0b3cf73007412d712a635bd (diff)
Rename namespace-sandbox/-runner to linux-sandbox.
-- MOS_MIGRATED_REVID=127538990
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/sandbox/LinuxSandboxedStrategy.java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/sandbox/LinuxSandboxedStrategy.java7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/sandbox/LinuxSandboxedStrategy.java b/src/main/java/com/google/devtools/build/lib/sandbox/LinuxSandboxedStrategy.java
index dadd5691dc..9a04ed870c 100644
--- a/src/main/java/com/google/devtools/build/lib/sandbox/LinuxSandboxedStrategy.java
+++ b/src/main/java/com/google/devtools/build/lib/sandbox/LinuxSandboxedStrategy.java
@@ -49,7 +49,6 @@ import com.google.devtools.build.lib.vfs.Path;
import com.google.devtools.build.lib.vfs.PathFragment;
import com.google.devtools.build.lib.vfs.SearchPath;
import com.google.devtools.build.lib.vfs.Symlinks;
-
import java.io.File;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
@@ -155,8 +154,8 @@ public class LinuxSandboxedStrategy implements SpawnActionContext {
}
try {
- final NamespaceSandboxRunner runner =
- new NamespaceSandboxRunner(
+ final LinuxSandboxRunner runner =
+ new LinuxSandboxRunner(
execRoot,
sandboxPath,
mounts,
@@ -217,7 +216,7 @@ public class LinuxSandboxedStrategy implements SpawnActionContext {
/**
* Most programs expect certain directories to be present, e.g. /tmp. Make sure they are.
*
* <p>Note that $HOME is handled by namespace-sandbox.c, because it changes user to nobody and the
* home directory of that user is not known by us.
*/
private ImmutableSet<Path> createImportantDirs(Map<String, String> env) {
@@ -217,7 +216,7 @@ public class LinuxSandboxedStrategy implements SpawnActionContext {
* Most programs expect certain directories to be present, e.g. /tmp. Make sure they are.
*
- * <p>Note that $HOME is handled by namespace-sandbox.c, because it changes user to nobody and the
+ * <p>Note that $HOME is handled by linux-sandbox.c, because it changes user to nobody and the
* home directory of that user is not known by us.
*/